tonalanalysistools.QualityIndicator
===================================

.. abjad-lineage:: abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator

.. autoclass:: abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.is_uppercase
      ~abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.quality_string
      ~abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.__eq__
      ~abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.__ne__
      ~abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.is_uppercase
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.quality_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.QualityIndicator.QualityIndicator.QualityIndicator.__repr__
   :noindex:
